"use strict";

Object.defineProperty(exports, "__esModule", {
    value: true
});

function _toConsumableArray(arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) { arr2[i] = arr[i]; } return arr2; } else { return Array.from(arr); } }

var KATAKANA_HIRAGANA_SHIFT = "\u3041".charCodeAt(0) - "\u30A1".charCodeAt(0);
var HIRAGANA_KATAKANA_SHIFT = "\u30A1".charCodeAt(0) - "\u3041".charCodeAt(0);

/**
 * Check if given char is a hiragana
 *
 * @param {string} ch Given char
 * @return {boolean} if given char is a hiragana
 */
var isHiragana = function isHiragana(ch) {
    ch = ch[0];
    return ch >= "\u3040" && ch <= "\u309F";
};

/**
 * Check if given char is a katakana
 *
 * @param {string} ch Given char
 * @return {boolean} if given char is a katakana
 */
var isKatakana = function isKatakana(ch) {
    ch = ch[0];
    return ch >= "\u30A0" && ch <= "\u30FF";
};

/**
 * Check if given char is a kana
 *
 * @param {string} ch Given char
 * @return {boolean} if given char is a kana
 */
var isKana = function isKana(ch) {
    return isHiragana(ch) || isKatakana(ch);
};

/**
 * Check if given char is a kanji
 *
 * @param {string} ch Given char
 * @return {boolean} if given char is a kanji
 */
var isKanji = function isKanji(ch) {
    ch = ch[0];
    return ch >= "\u4E00" && ch <= "\u9FCF" || ch >= "\uF900" && ch <= "\uFAFF" || ch >= "\u3400" && ch <= "\u4DBF";
};

/**
 * Check if given char is a Japanese
 *
 * @param {string} ch Given char
 * @return {boolean} if given char is a Japanese
 */
var isJapanese = function isJapanese(ch) {
    return isKana(ch) || isKanji(ch);
};

/**
 * Check if given string has hiragana
 *
 * @param {string} str Given string
 * @return {boolean} if given string has hiragana
 */
var hasHiragana = function hasHiragana(str) {
    for (var i = 0; i < str.length; i++) {
        if (isHiragana(str[i])) return true;
    }
    return false;
};

/**
 * Check if given string has katakana
 *
 * @param {string} str Given string
 * @return {boolean} if given string has katakana
 */
var hasKatakana = function hasKatakana(str) {
    for (var i = 0; i < str.length; i++) {
        if (isKatakana(str[i])) return true;
    }
    return false;
};

/**
 * Check if given string has kana
 *
 * @param {string} str Given string
 * @return {boolean} if given string has kana
 */
var hasKana = function hasKana(str) {
    for (var i = 0; i < str.length; i++) {
        if (isKana(str[i])) return true;
    }
    return false;
};

/**
 * Check if given string has kanji
 *
 * @param {string} str Given string
 * @return {boolean} if given string has kanji
 */
var hasKanji = function hasKanji(str) {
    for (var i = 0; i < str.length; i++) {
        if (isKanji(str[i])) return true;
    }
    return false;
};

/**
 * Check if given string has Japanese
 *
 * @param {string} str Given string
 * @return {boolean} if given string has Japanese
 */
var hasJapanese = function hasJapanese(str) {
    for (var i = 0; i < str.length; i++) {
        if (isJapanese(str[i])) return true;
    }
    return false;
};

var toRawHiragana = function toRawHiragana(str) {
    return [].concat(_toConsumableArray(str)).map(function (ch) {
        if (ch > "\u30A0" && ch < "\u30F7") {
            return String.fromCharCode(ch.charCodeAt(0) + KATAKANA_HIRAGANA_SHIFT);
        }
        return ch;
    }).join("");
};

var toRawKatakana = function toRawKatakana(str) {
    return [].concat(_toConsumableArray(str)).map(function (ch) {
        if (ch > "\u3040" && ch < "\u3097") {
            return String.fromCharCode(ch.charCodeAt(0) + HIRAGANA_KATAKANA_SHIFT);
        }
        return ch;
    }).join("");
};

var toRawRomaji = function toRawRomaji(str) {
    var roman = {

        "１": "1",
        "２": "2",
        "３": "3",
        "４": "4",
        "５": "5",
        "６": "6",
        "７": "7",
        "８": "8",
        "９": "9",
        "０": "0",
        "！": "!",
        "“": "\"",
        "”": "\"",
        "＃": "#",
        "＄": "$",
        "％": "%",
        "＆": "&",
        "’": "'",
        "（": "(",
        "）": ")",
        "＝": "=",
        "～": "~",
        "｜": "|",
        "＠": "@",
        "‘": "`",
        "＋": "+",
        "＊": "*",
        "；": ";",
        "：": ":",
        "＜": "<",
        "＞": ">",
        "、": ",",
        "。": ".",
        "／": "/",
        "？": "?",
        "＿": "_",
        "・": "･",
        "「": "\"",
        "」": "\"",
        "｛": "{",
        "｝": "}",
        "￥": "\\",
        "＾": "^",

        ふぁ: "fa",
        ふぃ: "fi",
        ふぇ: "fe",
        ふぉ: "fo",
        ファ: "fa",
        フィ: "fi",
        フェ: "fe",
        フォ: "fo",

        きゃ: "kya",
        きゅ: "kyu",
        きょ: "kyo",
        しゃ: "sha",
        しゅ: "shu",
        しょ: "sho",
        ちゃ: "cha",
        ちゅ: "chu",
        ちょ: "cho",
        にゃ: "nya",
        にゅ: "nyu",
        にょ: "nyo",
        ひゃ: "hya",
        ひゅ: "hyu",
        ひょ: "hyo",
        みゃ: "mya",
        みゅ: "myu",
        みょ: "myo",
        りゃ: "rya",
        りゅ: "ryu",
        りょ: "ryo",

        キャ: "kya",
        キュ: "kyu",
        キョ: "kyo",
        シャ: "sha",
        シュ: "shu",
        ショ: "sho",
        チャ: "cha",
        チュ: "chu",
        チョ: "cho",
        ニャ: "nya",
        ニュ: "nyu",
        ニョ: "nyo",
        ヒャ: "hya",
        ヒュ: "hyu",
        ヒョ: "hyo",
        ミャ: "mya",
        ミュ: "myu",
        ミョ: "myo",
        リャ: "rya",
        リュ: "ryu",
        リョ: "ryo",

        ふゃ: "fya",
        ふゅ: "fyu",
        ふょ: "fyo",
        ぴゃ: "pya",
        ぴゅ: "pyu",
        ぴょ: "pyo",
        びゃ: "bya",
        びゅ: "byu",
        びょ: "byo",
        ぢゃ: "dya",
        ぢゅ: "dyu",
        ぢょ: "dyo",
        じゃ: "ja",
        じゅ: "ju",
        じょ: "jo",
        ぎゃ: "gya",
        ぎゅ: "gyu",
        ぎょ: "gyo",

        フャ: "fya",
        フュ: "fyu",
        フョ: "fyo",
        ピャ: "pya",
        ピュ: "pyu",
        ピョ: "pyo",
        ビャ: "bya",
        ビュ: "byu",
        ビョ: "byo",
        ヂャ: "dya",
        ヂュ: "dyu",
        ヂョ: "dyo",
        ジャ: "ja",
        ジュ: "ju",
        ジョ: "jo",
        ギャ: "gya",
        ギュ: "gyu",
        ギョ: "gyo",

        ぱ: "pa",
        ぴ: "pi",
        ぷ: "pu",
        ぺ: "pe",
        ぽ: "po",
        ば: "ba",
        び: "bi",
        ぶ: "bu",
        べ: "be",
        ぼ: "bo",
        だ: "da",
        ぢ: "di",
        づ: "du",
        で: "de",
        ど: "do",
        ざ: "za",
        じ: "ji",
        ず: "zu",
        ぜ: "ze",
        ぞ: "zo",
        が: "ga",
        ぎ: "gi",
        ぐ: "gu",
        げ: "ge",
        ご: "go",

        パ: "pa",
        ピ: "pi",
        プ: "pu",
        ペ: "pe",
        ポ: "po",
        バ: "ba",
        ビ: "bi",
        ブ: "bu",
        ベ: "be",
        ボ: "bo",
        ダ: "da",
        ヂ: "di",
        ヅ: "du",
        デ: "de",
        ド: "do",
        ザ: "za",
        ジ: "ji",
        ズ: "zu",
        ゼ: "ze",
        ゾ: "zo",
        ガ: "ga",
        ギ: "gi",
        グ: "gu",
        ゲ: "ge",
        ゴ: "go",

        わ: "wa",
        ゐ: "wi",
        ゑ: "we",
        を: "wo",
        ら: "ra",
        り: "ri",
        る: "ru",
        れ: "re",
        ろ: "ro",
        や: "ya",
        ゆ: "yu",
        よ: "yo",
        ま: "ma",
        み: "mi",
        む: "mu",
        め: "me",
        も: "mo",
        は: "ha",
        ひ: "hi",
        ふ: "hu",
        へ: "he",
        ほ: "ho",
        な: "na",
        に: "ni",
        ぬ: "nu",
        ね: "ne",
        の: "no",
        た: "ta",
        ち: "ti",
        つ: "tsu",
        て: "te",
        と: "to",
        さ: "sa",
        し: "si",
        す: "su",
        せ: "se",
        そ: "so",
        か: "ka",
        き: "ki",
        く: "ku",
        け: "ke",
        こ: "ko",
        あ: "a",
        い: "i",
        う: "u",
        え: "e",
        お: "o",
        ぁ: "a",
        ぃ: "i",
        ぅ: "u",
        ぇ: "e",
        ぉ: "o",
        ゃ: "ya",
        ゅ: "yu",
        ょ: "yo",

        ワ: "wa",
        ヰ: "wi",
        ヱ: "we",
        ヲ: "wo",
        ラ: "ra",
        リ: "ri",
        ル: "ru",
        レ: "re",
        ロ: "ro",
        ヤ: "ya",
        ユ: "yu",
        ヨ: "yo",
        マ: "ma",
        ミ: "mi",
        ム: "mu",
        メ: "me",
        モ: "mo",
        ハ: "ha",
        ヒ: "hi",
        フ: "hu",
        ヘ: "he",
        ホ: "ho",
        ナ: "na",
        ニ: "ni",
        ヌ: "nu",
        ネ: "ne",
        ノ: "no",
        タ: "ta",
        チ: "ti",
        ツ: "tsu",
        テ: "te",
        ト: "to",
        サ: "sa",
        シ: "si",
        ス: "su",
        セ: "se",
        ソ: "so",
        カ: "ka",
        キ: "ki",
        ク: "ku",
        ケ: "ke",
        コ: "ko",
        ア: "a",
        イ: "i",
        ウ: "u",
        エ: "e",
        オ: "o",
        ァ: "a",
        ィ: "i",
        ゥ: "u",
        ェ: "e",
        ォ: "o",
        ャ: "ya",
        ュ: "yu",
        ョ: "yo",

        ヶ: "ke",
        ヵ: "ka",
        ん: "n",
        ン: "n",
        ー: "-",
        "　": " "

    };
    var reg_tsu = /っ([bcdfghijklmnopqrstuvwyz])/gm;
    var reg_xtsu = /っ/gm;

    var pnt = 0;
    var max = str.length;
    var ch = void 0;
    var r = void 0;
    var result = "";

    while (pnt <= max) {
        if (r = roman[str.substring(pnt, pnt + 2)]) {
            result += r;
            pnt += 2;
        } else {
            result += (r = roman[ch = str.substring(pnt, pnt + 1)]) ? r : ch;
            pnt += 1;
        }
    }
    result = result.replace(reg_tsu, "$1$1");
    result = result.replace(reg_xtsu, "tsu");
    return result;
};

var getStrType = function getStrType(str) {
    // 0 for pure kanji,1 for kanji-hira(kana)-mixed,2 for pure hira(kana),3 for others
    var hasKJ = false;
    var hasHK = false;
    for (var i = 0; i < str.length; i++) {
        if (isKanji(str[i])) {
            hasKJ = true;
        } else if (isHiragana(str[i]) || isKatakana(str[i])) {
            hasHK = true;
        }
    }
    if (hasKJ && hasHK) return 1;else if (hasKJ) return 0;else if (hasHK) return 2;
    return 3;
};

var splitObjArray = function splitObjArray(arr, prop, split) {
    split = split || "";
    var result = "";
    for (var i = 0; i < arr.length; i++) {
        if (i !== arr.length - 1) {
            result += "" + arr[i][prop] + split;
        } else {
            result += arr[i][prop];
        }
    }
    return result;
};

exports.getStrType = getStrType;
exports.isHiragana = isHiragana;
exports.isKatakana = isKatakana;
exports.isKana = isKana;
exports.isKanji = isKanji;
exports.isJapanese = isJapanese;
exports.hasHiragana = hasHiragana;
exports.hasKatakana = hasKatakana;
exports.hasKana = hasKana;
exports.hasKanji = hasKanji;
exports.hasJapanese = hasJapanese;
exports.toRawHiragana = toRawHiragana;
exports.toRawKatakana = toRawKatakana;
exports.toRawRomaji = toRawRomaji;
exports.splitObjArray = splitObjArray;